@@ -2,7 +2,7 @@
 * telnet.cpp:
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: telnet.cpp,v 1.5 2002/03/25 14:49:33 bozo Exp $
+* $Id: telnet.cpp,v 1.7 2002/08/14 11:13:27 tooney Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -410,7 +410,7 @@ void C_TelnetSession::ProcessData()
         case IAC:
         {
           // Telnet negociation or special char
-          printf("negociation: %x %x\n", cData[iPos+1], cData[iPos+2]);
+//          printf("negociation: %x %x\n", cData[iPos+1], cData[iPos+2]);
           m_cBuffer[0] = IAC;
           m_cBuffer.SetSize(1);
           m_iMode = CONFIG_MODE;
@@ -420,7 +420,7 @@ void C_TelnetSession::ProcessData()
         case TELOPT_OUTMRK:
         {
           // Telnet special chars
-          printf("output marking: %x %x\n", cData[iPos+1], cData[iPos+2]);
+//          printf("output marking: %x %x\n", cData[iPos+1], cData[iPos+2]);
           m_cBuffer[0] = TELOPT_OUTMRK;
           m_cBuffer.SetSize(1); 
           m_iMode = CONTROL_MODE;
@@ -579,7 +579,7 @@ void C_TelnetSession::ExecLogin()
     C_String strPasswd = m_cCmdLine.GetCmdLine();
     
     // Authentication (to do)
-    int iRc = Authentificate(m_strLogin, strPasswd);
+    int iRc = Authenticate(m_strLogin, strPasswd);
 
     if(!iRc)
     {
